<?php
// Version: 2.0 RC4; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '2.0 RC3';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as opposed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status separate from topic icons? */
	$settings['separate_sticky_lock'] = true;

	/* Does this theme use the strict doctype? */
	$settings['strict_doctype'] = false;

	/* Does this theme use post previews on the message index? */
	$settings['message_index_preview'] = false;

	/* Set the following variable to true if this theme requires the optional theme strings file to be loaded. */
	$settings['require_theme_strings'] = false;
}

// The main sub template above the content.
function template_html_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '>
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title_html_safe'], '" />', !empty($context['meta_keywords']) ? '
	<meta name="keywords" content="' . $context['meta_keywords'] . '" />' : '', '
	<title>', $context['page_title_html_safe'], '</title>';

	// Please don't index these Mr Robot.
	if (!empty($context['robot_no_index']))
		echo '
	<meta name="robots" content="noindex" />';

	// Present a canonical url for search engines to prevent duplicate content in their indices.
	if (!empty($context['canonical_url']))
		echo '
	<link rel="canonical" href="', $context['canonical_url'], '" />';

	// The ?rc3 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/index', $context['theme_variant'], '.css?rc3" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/print.css?rc3" media="print" />';
    // IE7 needs some fixes for styles.
	if ($context['browser']['is_ie7'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ie7.css" />';
	// ..and IE6!
	elseif ($context['browser']['is_ie6'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ie6.css" />';
	// Firefox - all versions - too!
	elseif ($context['browser']['is_firefox'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/ff.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" />
	<link rel="search" href="', $scripturl, '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']) && (!empty($modSettings['allow_guestAccess']) || $context['user']['is_logged']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name_html_safe'], ' - ', $txt['rss'], '" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="', $scripturl, '?board=', $context['current_board'], '.0" />';

	// Some browsers need an extra stylesheet due to bugs/compatibility issues.
	foreach (array('ie7', 'ie6', 'ie8', 'webkit') as $cssfix)
		if ($context['browser']['is_' . $cssfix])
			echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/css/', $cssfix, '.css" />';

	// RTL languages require an additional stylesheet.
	if ($context['right_to_left'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/css/rtl.css" />';

	echo '
	<script type="text/javascript" src="', $settings['theme_url'], '/SmfProRC3/jquery.js"></script>
	<script type="text/javascript" src="', $settings['theme_url'], '/SmfProRC3/interface.js"></script>
	<script type="text/javascript" src="', $settings['default_theme_url'], '/scripts/script.js?rc3"></script>
	<script type="text/javascript" src="', $settings['theme_url'], '/scripts/theme.js?rc3"></script>
	
  <script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
	$(document).ready(
		function()
		{
			$("#dock").Fisheye(
				{
					maxWidth: 80,
					items: "a",
					itemsText: "span",
					container: ".dock-container",
					itemWidth: 40,
					proximity: 90,
					halign : "center"
				}
			)
		}
	);
  	// ]]></script>
	
	<script type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_default_theme_url = "', $settings['default_theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";', $context['show_pm_popup'] ? '
		var fPmPopup = function ()
		{
			if (confirm("' . $txt['show_personal_messages'] . '"))
				window.open(smf_prepareScriptUrl(smf_scripturl) + "action=pm");
		}
		addLoadEvent(fPmPopup);' : '', '
		var ajax_notification_text = "', $txt['ajax_in_progress'], '";
		var ajax_notification_cancel_text = "', $txt['modify_cancel'], '";
	// ]]></script>
<script language="JavaScript" type="text/javascript" src="', $settings['theme_url'], '/jquery.min.js"></script>
	<script language="JavaScript" type="text/javascript" src="', $settings['theme_url'], '/style-degistirici.js"></script>';
	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'];

	echo '
 </head>
<body>';
}

function template_body_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo !empty($settings['forum_width']) ? '
<div id="wrapper" style="width: ' . $settings['forum_width'] . '"/>' : '', '
<div id="mainframe">
<div id="header"><div class="frame">
		<div id="top_section">

						<h1 class="forumtitle">
				<a href="', $scripturl, '">', empty($context['header_logo_url_html_safe']) ? $context['forum_name'] : '<img src="' . $context['header_logo_url_html_safe'] . '" alt="' . $context['forum_name'] . '" />', '</a>
			</h1></div>';

	// the upshrink image, right-floated
	echo '
			<img id="upshrink" src="', $settings['images_url'], '/upshrink.png" alt="*" title="', $txt['upshrink_description'], '" style="display: none;" />';

	

		// display user name
	echo '
		<table width="100%" cellspacing="1" cellpadding="5" class="bordercolor" border="0" >
			<tr>';
			
	echo '
							<td class="windowbg2" width="100%" valign="middle" align="left">
	  ', theme_linktree(), '  							</td>';

	echo '
							<td width="150" valign="top" class="windowbg"><span class="middletext" style="display:block;width:230px;">';
							
	if ($context['user']['is_logged'] && $context['allow_pm'])
	{
		echo ((isset($current_action) && $curent_action == 'pm') || $context['browser']['is_ie6']) ? '' : '' , '
<a href="?language=turkish"><img alt="Trke" src="', $settings['images_url'], '/tr.gif" align="right" hspace="3" border="0" /></a>   
                            <a href="?language=english"><img alt="English" src="', $settings['images_url'], '/en.gif" align="right" hspace="3" border="0" /></a>
                  
<span style="font-size: 100%;"> ', $txt['hello_member_ndt'], ' <font style="font-size: 8pt" color="#000000"><b>', $context['user']['name'] , '</font></span><br>
					<a href="', $scripturl, '?action=pm">', $txt['your_pms'], ': <a href="', $scripturl, '?action=pm">', $context['user']['messages'], '</a></b> ', $txt['newmessages3'], ': <a href="', $scripturl, '?action=pm">', $context['user']['unread_messages'], '.<br />
					<a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a> <br />
					<a href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a><br />
					<span>' , $context['current_time'], '</span><br />';
                       // Show the total time logged in?
		if (!empty($context['user']['total_time_logged_in']))
		{
			echo '
								', $txt['totalTimeLogged1']; echo' <br> ';

			// If days is just zero, don't bother to show it.
			if ($context['user']['total_time_logged_in']['days'] > 0)
				echo $context['user']['total_time_logged_in']['days'] . $txt['totalTimeLogged2'];

			// Same with hours - only show it if it's above zero.
			if ($context['user']['total_time_logged_in']['hours'] > 0)
				echo $context['user']['total_time_logged_in']['hours'] . $txt['totalTimeLogged3'];

			// But, let's always show minutes - Time wasted here: 0 minutes ;).
			echo $context['user']['total_time_logged_in']['minutes'], $txt['totalTimeLogged4'], '<br />';
		}
		echo '				</span>';     
                    if (!empty($context['user']['avatar']))
		echo '
							<td class="windowbg" valign="middle">', $context['user']['avatar']['image'], '</td>';

	}
	
echo '
</span>'; 



	if ($context['user']['is_guest'])
	{
		echo '
								<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>

								                        <form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" class="middletext" style="margin: 3px 1ex 1px 0;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
					<select name="cookielength">
						<option value="60">', $txt['one_hour'], '</option>
						<option value="1440">', $txt['one_day'], '</option>
						<option value="10080">', $txt['one_week'], '</option>
						<option value="43200">', $txt['one_month'], '</option>
						<option value="-1" selected="selected">', $txt['forever'], '</option>
					</select>
                        <span class="quick" style="display: block;">
                        <span class="yoo-login">
                           <span class="login">
                              <span class="username">
                              <input type="text" name="user" size="18" alt="' , $txt[username] , '" value="' , $txt[username] , '" onfocus="if(this.value==\'' , $txt[username] , '\')value=\'\';" onblur="if(this.value==\'\')value=\'' , $txt[username] , '\';"  />
                              </span>
                              <span class="password">
                              <input type="password" name="passwrd" size="10" value="Password" onfocus="if(this.value==\'Password\')value=\'\';" onblur="if(this.value==\'\')value=\'Password\';" />
                              </span>
                           <span class="login-button-icon">
                              <input type="submit" value="', $txt['login'], '" class="button_submit" />
                           </span>
                           <span class="lostpassword">
                              <a href="', $scripturl, '?action=reminder" title="', $txt['forgot_your_password'] ,'"></a>
                           </span>
                           <span class="activatecode">
                           <a href="' . $scripturl . '?action=activate" title="', $txt['activate_code'] ,'"></a>
                           </span>
                           <span class="registration">
                           <a href="', $scripturl, '?action=register" title="', $txt['register'] ,'"></a>
                           </span><br /><br />
                           <input type="hidden" name="hash_passwrd" value="" />
                           </span>           
                        </span>
                        </span>
                        </form>';
	}

	echo '
				</td>
			</tr>
		</table>
	</div>';

// Show the menu here, according to the menu sub template.
	template_dock_menu ();
echo '
			<br class="clear" />';

		// Show the navigation tree.
		theme_linktree();

		echo '
	</div></div>';

	// The main content should go here.
	echo '
	<div id="content_section"><div class="frame">
		<div id="main_content_section">';
}

function template_body_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
		</div>
	</div></div>';

		// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '
	<div id="footer_section"><div class="frame">
		<ul class="reset">
			<li class="copyright">', theme_copyright(), '</li>
			<li><a id="button_xhtml" href="http://validator.w3.org/check/referer" target="_blank" class="new_win" title="', $txt['valid_xhtml'], '"><span>', $txt['xhtml'], '</span></a></li>
			', !empty($modSettings['xmlnews_enable']) && (!empty($modSettings['allow_guestAccess']) || $context['user']['is_logged']) ? '<li><a id="button_rss" href="' . $scripturl . '?action=.xml;type=rss" class="new_win"><span>' . $txt['rss'] . '</span></a></li>' : '', '
			<li class="last"><a id="button_wap2" href="', $scripturl , '?wap2" class="new_win"><span>', $txt['wap2'], '</span></a></li>
		</ul>';
 echo '
	
	<div align="center" class="smalltext"><a href="http://forum.birhayaldi.com/index.php/">[SMF Pro ALPHA 2.0 RC4]</a></div>';


	// Show the load time?
	if ($context['show_load_time'])
		echo '
		<p class="smalltext" id="show_loadtime">', $txt['page_created'], $context['load_time'], $txt['seconds_with'], $context['load_queries'], $txt['queries'], '</p>';

	echo '
	</div>
</div>';
}

function template_html_below()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	echo '
</body></html>';

}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree($force_show = false)
{
	global $context, $settings, $options, $shown_linktree;

	// If linktree is empty, just return - also allow an override.
	if (empty($context['linktree']) || (!empty($context['dont_default_linktree']) && !$force_show))
		return;

	//!!! Temporarily don't do it twice.
	if (!empty($shown_linktree))
		return;
	$shown_linktree = true;

	echo '
	<ul id="linktree">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		echo '
		<li', ($link_num == count($context['linktree']) - 1) ? ' class="last"' : '', '>';
// Show the | | |-[] Folders.
		if (!$settings['linktree_inline'])
		{
			if ($link_num > 0)
				echo str_repeat('<img src="' . $settings['images_url'] . '/icons/linktree_main.gif" alt="| " border="0" />', $link_num - 1), '<img src="' . $settings['images_url'] . '/icons/linktree_side.gif" alt="|-" border="0" />';
			echo '<img src="' . $settings['images_url'] . '/icons/folder_open.gif" alt="+" border="0" />&nbsp; ';
		}
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo $settings['linktree_link'] && isset($tree['url']) ? '
			<a href="' . $tree['url'] . '"><span>' . $tree['name'] . '</span></a>' : '<span>' . $tree['name'] .'</span>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo $settings['linktree_inline'] ? ' &nbsp;|&nbsp; ' : '<br />';
		echo '
		</li>';
	}
	echo '
	</ul>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '
		<div id="main_menu">
			<ul class="dropmenu" id="menu_nav">';

	foreach ($context['menu_buttons'] as $act => $button)
	{
		echo '
				<li id="button_', $act, '">
					<a class="', $button['active_button'] ? 'active ' : '', 'firstlevel" href="', $button['href'], '"', isset($button['target']) ? ' target="' . $button['target'] . '"' : '', '>
						<span class="', isset($button['is_last']) ? 'last ' : '', 'firstlevel">', $button['title'], '</span>
					</a>';
		if (!empty($button['sub_buttons']))
		{
			echo '
					<ul>';

			foreach ($button['sub_buttons'] as $childbutton)
			{
				echo '
						<li>
							<a href="', $childbutton['href'], '"', isset($childbutton['target']) ? ' target="' . $childbutton['target'] . '"' : '', '>
								<span', isset($childbutton['is_last']) ? ' class="last"' : '', '>', $childbutton['title'], !empty($childbutton['sub_buttons']) ? '...' : '', '</span>
							</a>';
				// 3rd level menus :)
				if (!empty($childbutton['sub_buttons']))
				{
					echo '
							<ul>';

					foreach ($childbutton['sub_buttons'] as $grandchildbutton)
						echo '
								<li>
									<a', $grandchildbutton['active_button'] ? ' class="active"' : '', ' href="', $grandchildbutton['href'], '"', isset($grandchildbutton['target']) ? ' target="' . $grandchildbutton['target'] . '"' : '', '>
										<span', isset($grandchildbutton['is_last']) ? ' class="last"' : '', '>', $grandchildbutton['title'], '</span>
									</a>
								</li>';

					echo '
						</ul>';
				}

				echo '
						</li>';
			}
			echo '
					</ul>';
		}
		echo '
				</li>';
	}

	echo '
			</ul>
		</div>';

}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $strip_options = array())
{
	global $settings, $context, $txt, $scripturl;

	if (!is_array($strip_options))
		$strip_options = array();

	// Create the buttons...
	$buttons = array();
	foreach ($button_strip as $key => $value)
	{
		if (!isset($value['test']) || !empty($context[$value['test']]))
			$buttons[] = '
				<li><a' . (isset($value['id']) ? ' id="button_strip_' . $value['id'] . '"' : '') . ' class="button_strip_' . $key . '' . (isset($value['active']) ? ' active' : '') . '" href="' . $value['url'] . '"' . (isset($value['custom']) ? ' ' . $value['custom'] : '') . '><span>' . $txt[$value['text']] . '</span></a></li>';
	}

	// No buttons? No button strip either.
	if (empty($buttons))
		return;

	// Make the last one, as easy as possible.
	$buttons[count($buttons) - 1] = str_replace('<span>', '<span class="last">', $buttons[count($buttons) - 1]);

	echo '
		<div class="buttonlist', !empty($direction) ? ' align_' . $direction : '', '"', (empty($buttons) ? ' style="display: none;"' : ''), (!empty($strip_options['id']) ? ' id="' . $strip_options['id'] . '"': ''), '>
			<ul>',
				implode('', $buttons), '
			</ul>
		</div>';
}
function template_dock_menu ()
{
	
		global $context, $modSettings, $user_info, $settings, $options, $scripturl, $txt;


echo '
<div class="dock" id="dock">
  <div class="dock-container">';
echo '
	  <a class="dock-item" href="', $scripturl, '" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/home.png" alt="' . $txt['home'] . '" /><span>' . $txt['home'] . '</span></a> ';


echo '
	  <a class="dock-item" href="', $scripturl, '?action=help" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/help.png" alt="' . $txt['help'] . '" /><span>' . $txt['help'] . '</span></a> ';

echo '
	  <a class="dock-item" href="', $scripturl, '?action=search" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/search.png" alt="' . $txt['search'] . '" /><span>' . $txt['search'] . '</span></a> ';

if ($context['allow_edit_profile'])
				echo '<a class="dock-item" href="', $scripturl, '?action=profile" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/profile.png" alt="' . $txt['profile'] .'" /><span>' . $txt['profile'], '</span></a>';

if ($context['allow_pm'])
{
	if ( $context['user']['unread_messages'] >= 1 )
	{
	echo '<a class="dock-item" href="', $scripturl, '?action=pm" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/pmsome.png" alt="' . $txt['pm_short'] .'" /><span>' . $txt['pm_short'], '</span></a>';
} 
else {
	echo '<a class="dock-item" href="', $scripturl, '?action=pm" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/pm.png" alt="' . $txt['pm_short'] .'" /><span>' . $txt['pm_short'], '</span></a>';
}
}

		if ($context['allow_memberlist'])
				echo '<a class="dock-item" href="', $scripturl, '?action=mlist" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/members.png" alt="' . $txt['members'] .'" /><span>' . $txt['members'], '</span></a>';

if ($context['allow_calendar'])
				echo '<a class="dock-item" href="', $scripturl, '?action=calendar" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/cal.png" alt="' . $txt['calendar'] .'" /><span>' . $txt['calendar'], '</span></a>';

//if ($user_info['is_guest'] ? !empty($modSettings['contact_form_enable_guest_access']) : !empty($modSettings['contact_form_enable_member_access']))
//				echo '<a class="dock-item" href="', $scripturl, '?action=contact" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/contact.png" alt="' . $txt['contact'] .'" /><span>' . $txt['contact'], '</span></a>';
 
if ($context['allow_moderation_center'])
				echo '<a class="dock-item" href="', $scripturl, '?action=moderate" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/moderate.png" alt="' . $txt['moderate'] .'" /><span>' . $txt['moderate'], '</span></a>';
        
		if ($context['allow_admin'])
				echo '<a class="dock-item" href="', $scripturl, '?action=admin" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/admin.png" alt="' . $txt['admin'] .'" /><span>' . $txt['admin'], '</span></a>';

		if ($context['user']['is_logged'])
				echo '<a class="dock-item" href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/logout.png" alt="' . $txt['logout'] . '" /><span>' . $txt['logout'], '</span></a>';
                
		 if ($context['user']['is_guest'])		  
				echo '<a class="dock-item" href="', $scripturl, '?action=login" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/login.png" alt="' . $txt['login'] . '" /><span>' . $txt['login'], '</span></a>';
                
		  if ($context['user']['is_guest'])	
				echo '<a class="dock-item" href="', $scripturl, '?action=register" ><img src="' . $settings['theme_url'] . '/images/SmfProRC3', $context['theme_variant'], '/reg.png" alt="' . $txt['register'] . '" /><span>' . $txt['register'], '</span></a>';
echo '
  </div>
</div>';


}
?>